@@ -1,9 +1,9 @@
 ## File Name: gdd.R
-## File Version: 0.08
-## File Last Change: 2017-01-31 15:38:48
+## File Version: 0.11
 #################################################################
 # generalized distance discriminating method
-gdd <- function( data , q.matrix , theta , b , a  , skillclasses=NULL){
+gdd <- function( data , q.matrix , theta , b , a  , skillclasses=NULL)
+{
 	data <- as.matrix(data)
 	data_isna <- is.na( data )
 	dataresp <- as.matrix( 1 - data_isna )
@@ -20,8 +20,8 @@ gdd <- function( data , q.matrix , theta , b , a  , skillclasses=NULL){
 	# extract results
 	distmatrix <- res$dist
 	skillclass.est <- skillspace[ res$est_skill , ]
-	res <- list( "skillclass.est" = skillspace , "distmatrix" = distmatrix ,
-				  "skillspace" = skillspace , "theta" = theta )   
+	res <- list( skillclass.est = skillspace , distmatrix = distmatrix ,
+					skillspace = skillspace , theta = theta )   
 	return(res)
 }
 ###############################################################################
