@@ -1,20 +1,19 @@
 ## File Name: gdina_calc_individual_posterior.R
-## File Version: 0.01
-## File Last Change: 2017-06-04 18:36:59
+## File Version: 0.12
 
 gdina_calc_individual_posterior <- function(G, IP, attr.prob, p.xi.aj, L, I,
 		zeroprob.skillclasses, reduced.skillspace, item.patt.freq)
 {
-    # posterior probabilities  P( \alpha_l | X_i ) 
-	if (G== 1){ 
-		p.aj.xi <- outer( rep(1,IP), attr.prob ) * p.xi.aj 
+	# posterior probabilities  P( \alpha_l | X_i ) 
+	if (G==1){ 
+		p.aj.xi <- cdm_matrix2( x=attr.prob , nrow=IP) * p.xi.aj 
 	} else {
-		 p.aj.xi <- array( 0 , c( IP , L , G ) )
+		p.aj.xi <- array( 0 , c( IP , L , G ) )
 		for (gg in 1:G){
-			p.aj.xi[,,gg] <- outer( rep(1,IP), as.vector(attr.prob[,gg]) ) * p.xi.aj
+			p.aj.xi[,,gg] <- cdm_matrix2( x= as.vector(attr.prob[,gg]) , nrow=IP) * p.xi.aj 								
 		}
 	}
-			 
+
 	if (G == 1){ 
 		if ( ! is.null( zeroprob.skillclasses ) ){
 			p.aj.xi[ , zeroprob.skillclasses ] <- 0 
@@ -25,7 +24,7 @@ gdina_calc_individual_posterior <- function(G, IP, attr.prob, p.xi.aj, L, I,
 			attr.prob <- colSums( p.aj.xi * item.patt.freq / I )
 		}
 	}
-    if ( G > 1 ){ 					
+	if ( G > 1 ){
 		if ( ! is.null( zeroprob.skillclasses ) ){
 			for (gg in 1:G){ 
 				p.aj.xi[ , zeroprob.skillclasses , gg ] <- 0 
