@@ -1,6 +1,5 @@
 ## File Name: gdina_calc_prob.R
-## File Version: 0.01
-## File Last Change: 2017-06-04 18:28:02
+## File Version: 0.04
 
 gdina_calc_prob <- function( progress, iter, disp , J , L , aggr.attr.patt, Mj, delta,
 		linkfct)
@@ -14,24 +13,26 @@ gdina_calc_prob <- function( progress, iter, disp , J , L , aggr.attr.patt, Mj,
 	for (jj in 1:J){
 		ajj <- ( aggr.attr.patt[[jj]] )
 		mjjj <- Mj[[jj]][[1]][ ajj , ]
-		djj <- matrix( delta[[jj]] , L , length(delta[[jj]]) , byrow=TRUE )
+		djj <- matrix( delta[[jj]] , nrow=L , ncol=length(delta[[jj]]) , byrow=TRUE )
 		pj1[jj,] <- rowSums( mjjj * djj )
 		if (linkfct == "logit"){
 			pj1[jj,] <- stats::plogis( pj1[jj,] )
 		}
 		if (linkfct == "log"){
 			pj1[jj,] <- exp( pj1[jj,] )
-		}									
-	}									
-	#-- restrict probabilities in calculations									
+		}
+	}
+	#-- restrict probabilities in calculations
 	eps <- 1E-10
 	pj1[ pj1 < 0 ] <- eps
-	pj1[ pj1 > 1 ] <- 1 - eps		
-# cat( "\n Step 1a (calculate P(X_j|alpha_l)\n" ) ; a1 <- Sys.time() ; print(a1-a0) ; a0 <- a1
-	#-- create array								
+	pj1[ pj1 > 1 ] <- 1 - eps
+	#-- create array
 	pjM <- array( NA , dim=c(J,2,L) )
 	pjM[,1,] <- 1 - pj1
 	pjM[,2,] <- pj1		
 	#--- OUTPUT
 	return(pjM)			
 }		
+
+
+# cat( "\n Step 1a (calculate P(X_j|alpha_l)\n" ) ; a1 <- Sys.time() ; print(a1-a0) ; a0 <- a1
