@@ -1,9 +1,9 @@
 ## File Name: mcdina_prepare.R
-## File Version: 0.20
-## File Last Change: 2017-01-31 14:07:29
+## File Version: 0.22
 ##############################################
 # modify q-matrix
-mcdina.modify.qmatrix <- function( q.matrix , skillclasses){	
+mcdina.modify.qmatrix <- function( q.matrix , skillclasses)
+{
 	# create new q.matrix
 	K <- ncol(q.matrix) - 2
 	maxattr <- apply( q.matrix[,-c(1:2) ] , 2 , max )
@@ -25,9 +25,9 @@ mcdina.modify.qmatrix <- function( q.matrix , skillclasses){
 			for (zz in 1:(maxattr[kk] ) ){ # 	zz <- 1
 				name <- paste0( colnames(q.matrix)[kk+2] , ".L" , zz )
 				q.matrix1[ ,  name ] <- 1 * ( q.matrix[ , kk + 2] >= zz )
-						}
+			}
 			qmatrix_mod <- rbind( qmatrix_mod , qmatrix_mod.kk )		
-					}
+		}
 		qmatrix_mod$start <- c(1,cumsum( qmatrix_mod$maxattr)[ - K ] + 1  )
 		qmatrix_mod$end <- cumsum( qmatrix_mod$maxattr)
 		skillclasses0 <- skillclasses	
@@ -38,8 +38,8 @@ mcdina.modify.qmatrix <- function( q.matrix , skillclasses){
 			for (zz in 1:(maxattr[kk] ) ){ # 	zz <- 1
 				name <- paste0( colnames(q.matrix)[kk+2] , ".L" , zz )
 				skillclasses[ ,  name ] <- 1 * ( skillclasses[ , kk ] >= zz )
-						}
-					}	
+			}
+		}	
 		skillclasses <- skillclasses[ , - c(1:K) ]
 		rownames(skillclasses) <- .matrixstring( skillclasses , "P" )	
 		res$q.matrix <- q.matrix1
@@ -47,9 +47,9 @@ mcdina.modify.qmatrix <- function( q.matrix , skillclasses){
 		res$skillclasses0 <- skillclasses0
 		res$q.matrix0 <- q.matrix
 		res$qmatrix_mod <- qmatrix_mod		
-		}
+	}
 	return(res)
-	}	
+}	
 ########################################################	
 	
 ######################################################
@@ -62,76 +62,73 @@ mcdina.modify.qmatrix <- function( q.matrix , skillclasses){
 			q0 <- data.frame( "item" = 1:I , "categ" = 1 , 0+0*q.matrix )			
 			q.matrix <- rbind( q0 , q1 )
 			q.matrix <- q.matrix[ order( 100 * q.matrix$item + q.matrix$categ ) , ]
-					}
-				}
+		}
+	}
 	res <- list("dat"=dat , "q.matrix" = q.matrix )
 	return(res)
-		}
+}
 
 
 ###################################################
 # initial estimate of item parameters delta
-.mcdina.init.delta <- function( lc , lr ){
-    I <- max( lc$item )
+.mcdina.init.delta <- function( lc , lr )
+{
+	I <- max( lc$item )
 	lc$cats <- lc$cats
-	#	lc.cats <- lc$cats
-    CC <- max(lc$cats)
-    delta_ideal <- delta <- array( 0 , dim=c(I , CC , CC ) )
-    delta_ideal[ as.matrix( lc[ , c("item" , "cats" , "lr_index" ) ] ) ] <- 1
-    eps <- 1E-10
-    # define initial delta estimate
-    for (ii in 1:I){
-	    dii <- delta_ideal[ii,,]
+	CC <- max(lc$cats)
+	delta_ideal <- delta <- array( 0 , dim=c(I , CC , CC ) )
+	delta_ideal[ as.matrix( lc[ , c("item" , "cats" , "lr_index" ) ] ) ] <- 1
+	eps <- 1E-10
+	# define initial delta estimate
+	for (ii in 1:I){
+		dii <- delta_ideal[ii,,]
 		lcii <- lc[ lc$item == ii , ]
 		Ncii <- nrow(lcii)
-        for (cc in 1:CC){
-            dii.cc <- dii[,cc]
-            delta[ii,,cc] <- dii.cc * ( 0.8 / sum( dii.cc + eps) ) +
-                                (1-dii.cc) * ( .2 / sum( ( 1-dii.cc) + eps ) )
+		for (cc in 1:CC){
+			dii.cc <- dii[,cc]
+			delta[ii,,cc] <- dii.cc * ( 0.8 / sum( dii.cc + eps) ) +
+						(1-dii.cc) * ( .2 / sum( ( 1-dii.cc) + eps ) )
 			if (Ncii < CC ){ 
 				delta[ii,seq(Ncii+1,CC),cc] <- 0
 				delta[ii,,cc] <- delta[ii,,cc] / sum( delta[ii,,cc] )
-							}
-            if ( sum( dii.cc ) == 0 ){ delta[ii,,cc] <- 0 }
-						
-                        }
-                    }
-    res <- list( "delta" = delta , "delta_ideal" = delta_ideal )
-    return(res)
-        }
+			}
+			if ( sum( dii.cc ) == 0 ){ delta[ii,,cc] <- 0 }
+		}
+	}
+	res <- list( "delta" = delta , "delta_ideal" = delta_ideal )
+	return(res)
+}
 ############################################################
 
 ##########################################
 # preparation function for whole test
-.mcdina.prep.test.latent.response <- 
-function( q.matrix , K , TP , skillclasses , classes ){
+.mcdina.prep.test.latent.response <- function( q.matrix , K , TP , skillclasses , classes )
+{
 	I <- length( unique(q.matrix[,1]))
 	lr <- NULL
 	lc <- NULL
 	itemstat <- NULL
-    for (ii in 1:I){ 
-	   res <- .mcdina.prep.item.latent.response( ii , q.matrix , 
+	for (ii in 1:I){ 
+		res <- .mcdina.prep.item.latent.response( ii , q.matrix , 
 				K , TP , skillclasses , classes )
 		lr <- rbind( lr , res$lr )
 		lc <- rbind( lc , res$lc )
 		itemstat <- rbind( itemstat , res$itemstat )
-			}
+	}
 	res <- list("lr"=lr , "lc"=lc , "itemstat"=itemstat)			
 	return(res)
-		}
+}
 ###############################################		
 		
 ##############################################
 # compute preparation table for one item
-.mcdina.prep.item.latent.response <- 
-function( ii , q.matrix , K , TP , skillclasses , classes ){
+.mcdina.prep.item.latent.response <- function( ii , q.matrix , K , TP , skillclasses , classes )
+{
 	q.ii <- q.matrix[ q.matrix[,1] == ii , ]	
-#	classes <- rownames(skillclasses)
 	# categories
 	cats.ii <- q.ii[,2]
 	CC <- length(cats.ii)
 	# calculate relevant attributes
-#	qsum <- rowSums( q.ii[ , 1:K + 2  ] )
 	qsum <- rowSums( q.ii[ , 1:K + 2  ]  )
 	index.max <- which( qsum == max(qsum) )
 	# necessary attributes for item ii
@@ -146,7 +143,7 @@ function( ii , q.matrix , K , TP , skillclasses , classes ){
 		tmp1 <- skillclasses[ , attr.ii , drop=FALSE] %*% t( q.ii.red[cc,]  )
 		sk.ii1[ , cc] <- 1 * ( tmp1 >=  sum( q.ii.red[cc ,] ) ) 
 		sk.ii1[ , cc] <-  tmp1*sk.ii1[ , cc]
-				}				
+	}
 	sk.ii1 <- 1 * ( sk.ii1 > 0 )
 	v1.ii <- which( rowSums( sk.ii1 ) == 0 )
 	i5 <- which( rowSums( q.ii.red ) == 0 )
@@ -158,8 +155,7 @@ function( ii , q.matrix , K , TP , skillclasses , classes ){
 	lg <- "LR"
 	for (cc in 1:CC){
 		lg <- paste0( lg , ifelse( sk.ii2[,cc]==1 , cats.ii[cc] , "") )
-				}
-#	sk.ii3 <- cbind( sk.ii2 , lg )
+	}
 	groups <- sort( unique(lg) )
 	lr <- data.frame("item" = ii , "skillclass" = classes , 
 		"skillclass_index" = 1:TP , "lr" = lg )
@@ -184,17 +180,18 @@ function( ii , q.matrix , K , TP , skillclasses , classes ){
 	itemstat$N.attr <- length(attr.ii)
 	res <- list("lr"=lr , "lc"=lc , "itemstat"=itemstat)			
 	return(res)
-		}
+}
 ############################################################
 # calculates a string pattern consisting of matrix entries
 # matr <- skillclasses
 # string <- "Q"
-.matrixstring <- function( matr , string ){
+.matrixstring <- function( matr , string )
+{
 	VV <- ncol(matr)
 	l1 <- string
 	for ( vv in 1:VV){
 		l1 <- paste0( l1 , matr[,vv] )
-				}
+	}
 	return(l1)
-		}
+}
 #################################################################
