@@ -1,11 +1,11 @@
 ## File Name: numerical_Hessian.R
-## File Version: 0.15
-## File Last Change: 2017-01-31 14:07:29
+## File Version: 0.19
 
 ##############################################################################
 # numerical computation of the Hessian matrix
 numerical_Hessian <- function(par , FUN , h = 1E-5, gradient=FALSE, 
-      hessian = TRUE , ... ){
+		hessian = TRUE , diag_only = FALSE, ... )
+{
 
 	NP <- length(par)
 	
@@ -21,12 +21,11 @@ numerical_Hessian <- function(par , FUN , h = 1E-5, gradient=FALSE,
 	
 	#--- loop for computing f(x+h)
 	for (ii in 1:NP){
-		# ii <- 1
 		par1 <- par
 		par1[ii] <- par[ii] + hvec[ii]
 		fh[ii] <- FUN( x = par1 , ...)
 	}
-    
+
 	#--- computation of the gradient
 	if (gradient){
 		grad1 <- res <- ( fh - f0 ) / hvec
@@ -51,17 +50,19 @@ numerical_Hessian <- function(par , FUN , h = 1E-5, gradient=FALSE,
 			par1[ii] <- par[ii] + 2*hvec[ii]
 			f2h[ii] <- FUN( x = par1 , ... )
 		}	
-		#--- computation f(x+h,y+h) 	
-		for (ii in 1:NP){
-			for (jj in 1:NP){
-				if (ii < jj){
-					par1 <- par
-					par1[ii] <- par[ii] + hvec[ii]
-					par1[jj] <- par[jj] + hvec[jj]
-					fhh[ii,jj] <- fhh[jj,ii] <- FUN( x = par1 , ... )
-				}
-			}	
-		}	    
+		#--- computation f(x+h,y+h)
+		if ( ! diag_only ){		
+			for (ii in 1:NP){
+				for (jj in 1:NP){
+					if (ii < jj){
+						par1 <- par
+						par1[ii] <- par[ii] + hvec[ii]
+						par1[jj] <- par[jj] + hvec[jj]
+						fhh[ii,jj] <- fhh[jj,ii] <- FUN( x = par1 , ... )
+					}
+				}	
+			}	    
+		}
 		h_squared <- outer( hvec , hvec )		
 		hess <- ( fhh - fh1 - fh2 + f0 ) / h_squared
 		diag(hess) <- ( f2h - 2*fh + f0)/ hvec^2
@@ -69,7 +70,7 @@ numerical_Hessian <- function(par , FUN , h = 1E-5, gradient=FALSE,
 	}
 	
 	if ( gradient & hessian ){
-		res <- list( "grad" = grad1 , "hessian" = hess)	
+		res <- list( "grad" = grad1 , "hessian" = hess, "value"= f0)	
 	}	
 	return(res)
 }
