@@ -1,14 +1,15 @@
 ## File Name: slca_calc_loglikelihood.R
-## File Version: 0.06
-## File Last Change: 2017-10-05 16:39:15
+## File Version: 0.08
 
 slca_calc_loglikelihood <- function(Xlambda, delta, delta.designmatrix, XdesM, dimXdes, gwt0, dat, I, resp.ind.list,
-		G, use.freqpatt, ind.group, weights, Xlambda.constr.V, e2, V1)
+		G, use.freqpatt, ind.group, weights, Xlambda.constr.V, e2, V1, Xlambda_positive)
 {
 	#-- Xlambda constraint
 	if ( ! is.null(Xlambda.constr.V) ){
 		Xlambda <- slca_est_xlambda_constraint( Xlambda.constr.V=Xlambda.constr.V, V1=V1, e2=e2 ) 
 	}	
+	#-- positivity constraint
+	Xlambda <- cdm_positivity_restriction(x=Xlambda, positive=Xlambda_positive)		
 	#-- compute log-likelihood
 	probs <- slca_calc_prob( XdesM=XdesM, dimXdes=dimXdes, Xlambda=Xlambda ) 
 	pi.k <- slca_calc_class_probabilities( delta=delta, delta.designmatrix=delta.designmatrix )
